# Population

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 
**population_store_id** | **str** |  | 
**primary_key** | **str** |  | [optional] 
**partion_key** | **list[str]** |  | [optional] 
**population_store** | [**PopulationStore**](PopulationStore.md) |  | [optional] 
**model_populations** | [**list[ModelPopulation]**](ModelPopulation.md) |  | [optional] 
**outcomes** | [**list[OutcomeDefinition]**](OutcomeDefinition.md) |  | [optional] 
**interventions** | [**list[InterventionDefinition]**](InterventionDefinition.md) |  | [optional] 
**cohorts** | [**list[CohortDefinition]**](CohortDefinition.md) |  | [optional] 
**organization_id** | **str** |  | 
**organization** | [**Organization**](Organization.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

